# Table of Contents

- [application-modernization-track-report](<./application-modernization-track-report.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Step 7: Track and Report](<./Step-7-Track-and-Report.md>)
  - [Set Up a Key Performance Indicator (KPI) Dashboard](<./Step-7-Track-and-Report/Set-Up-a-Key-Performance-Indicator-KPI-Dashboard.md>)
  - [Create a Custom Modernization Dashboard](<./Step-7-Track-and-Report/Create-a-Custom-Modernization-Dashboard.md>)
  - [Track KPIs in the Architecture Executive Dashboard](<./Step-7-Track-and-Report/Track-KPIs-in-the-Architecture-Executive-Dashboard.md>)
  - [Scaling Your Modernization](<./Step-7-Track-and-Report/Scaling-Your-Modernization.md>)
  - [Was this page helpful?](<./Step-7-Track-and-Report/Was-this-page-helpful.md>)
